import React, { Component } from "react";
import { Button, Form, Row, Col } from "antd";
import "./index.less";

const { Item: FormItem } = Form;

class Index extends Component {
  constructor(props) {
    super(props);
    this.state = {};
    const {
      form: { getFieldDecorator },
    } = props;
    this.getFieldDecorator = getFieldDecorator;
  }

  /** 查询 */
  ok = () => {
    const {
      form: { validateFields },
      onOk,
    } = this.props;
    validateFields((err, values) => {
      if (!err) {
        onOk && onOk(values);
      }
    });
  };

  /** 重置 */
  reset = () => {
    const {
      form: { resetFields, validateFields },
      onReset,
    } = this.props;
    resetFields();
    validateFields((err, values) => {
      if (!err) {
        onReset && onReset(values);
      }
    });
  };

  render() {
    /* 
        // searchData数据实例
        const searchData = [
            {
                key: 'name',
                render: function () { // 不能是箭头函数（advancedSearch组件需要改变this指向）
                    return (
                        <FormItem label='name'>
                            {this.getFieldDecorator && this.getFieldDecorator('name', {
                                rules: [
                                    {
                                        required: true,
                                        message: 'Input something!',
                                    },
                                ],
                            })(<Input placeholder='placeholder' />)}
                        </FormItem>
                    );
                }
            },
        ];  
        */
    const {
      searchData = [],
      colSpan = 6, // 默认为6，必须是24的倍数
    } = this.props;
    const rowCount = parseInt(24 / colSpan, 10);
    const formLayout = {
      labelCol: {
        span: 8,
      },
      wrapperCol: {
        span: 14,
      },
    };
    const colArray = searchData.map(e => {
      const { key, render } = e;
      return (
        <Col key={key} span={colSpan}>
          {render && render.call(this)}
        </Col>
      );
    });
    const searchOperate = (
      <Col key="#searchOperate" span={colSpan}>
        <FormItem
          wrapperCol={{
            span: 22,
          }}
        >
          <div className="searchOperate">
            <Button
              type="primary"
              onClick={this.ok}
              className="ok"
            >
              查询
            </Button>
            <Button onClick={this.reset}>重置</Button>
          </div>
        </FormItem>
      </Col>
    );
    while ((colArray.length + 1) % rowCount !== 0) {
      colArray.push(<Col key={`spaceCol${colArray.length}`} span={colSpan} />);
    }

    colArray.push(searchOperate);
    const formItemArray = [];
    for (let i = 0; i < colArray.length; i++) {
      if ((i + 1) % rowCount === 0) {
        const rowTemp = colArray.slice(
          parseInt(i / rowCount, 10) * rowCount,
          i + 1
        );
        formItemArray.push(<Row key={`searchOperateRow${i}`}>{rowTemp}</Row>);
      }
    }
    return (
      <Form className="advancedSearch" {...formLayout}>
        {formItemArray}
      </Form>
    );
  }
}

export default Form.create({ name: "advancedSearch" })(Index);
