const path = require('path')
const { CleanWebpackPlugin } = require('clean-webpack-plugin')
const HtmlWebpackPlugin = require('html-webpack-plugin')

const DIST_PATH = path.resolve(__dirname, './example/dist')
const SRC_PATH  = path.resolve(__dirname, './src')

const config = {
  target: 'web',
  mode: 'development',
  entry: './example/index.js',
  output: {
    filename: 'js/[name].[hash:16].js',
    path: DIST_PATH,
  },
  plugins: [
    new CleanWebpackPlugin(),
    new HtmlWebpackPlugin({
      template: 'example/index.html',
      // title: 'Custom template',
      inject: 'body',
      minify: {
        html5: true
      },
      hash: false
    }),
  ],
  module: {
    rules: [
      {
        test: /\.(js|jsx)$/,
        exclude: /node_modules/,
        use: [
          {
            loader: 'babel-loader',
            options: {
              cacheDirectory: true, // 缓存
            },
          },
          {
            loader: 'eslint-loader',
            options: { // 这里的配置项参数将会被传递到 eslint 的 CLIEngine
              formatter: require('eslint-formatter-friendly'), // 指定错误报告的格式规范
              failOnError: true, // eslint报错，编译失败
              configFile: './.eslintrc.js',
            },
          },
        ],
      },
      {
        test: /\.(css|less)$/,
        use: [
          {
            loader: 'style-loader',
          },
          {
            loader: 'css-loader',
            options: {
              // modules: true,
            }
          },
          {
            loader: 'less-loader',
          },
        ],
      },
      {
        test: /\.(png|svg|jpg|gif)$/,
        use: {
          loader: 'url-loader',
          options: { limit: 3*1024 }, // 大于等于3k图片，进行Base64处理
        },
      },
    ],
  },
  resolve: {
    symlinks: false,
    extensions: ['.js', '.jsx', 'json'],
    alias: {
      '@src': SRC_PATH,
      '@utils': path.resolve(SRC_PATH, 'utils'),
      '@components': path.resolve(SRC_PATH, 'components'),
    },
  },
  devServer: {
    port: '8002',
    contentBase: path.join(__dirname, './example'),
    compress: false,
    historyApiFallback: true,
    hot: true,
    https: false,
    noInfo: true,
    open: true,
    proxy: {}
  }
}

module.exports =  config